**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *activation*: <i>sweep_sequencer</i>

 - *run_state*: None

 - *progress*: None

 - *profile*: Run a profile on the run to find performance problems

 - *cycles*: number of times the sequence is executed

 - *paused*: None

 - *recipe_folder*: None

 - *sequence_file*: None

 - *range_min*: use <i>measurement/sweep_sequencer/current_range_value</i> 
to update the setting you want to sweep

 - *range_max*: use <i>measurement/sweep_sequencer/current_range_value</i> 
to update the setting you want to sweep

 - *range_step*: use <i>measurement/sweep_sequencer/current_range_value</i> 
to update the setting you want to sweep

 - *range_num*: use <i>measurement/sweep_sequencer/current_range_value</i> 
to update the setting you want to sweep

 - *range_sweep_type*: None

 - *current_range_value*: None

 - *ignore_sweep*: None

